from distutils.core import setup

setup(name='stringdiff',
    version='1.0',
    description='Use edit distance to compare strings',
    license='MIT',
    author='Lillian Zhu',
    author_email='zhuy0713@gmail.com',
    url='https://github.com/yining0713/edit-distance'
    )
